@@ -36,18 +36,22 @@ class DriverElement(DrissionElement):
         """返回元素所有属性及值"""
         js = '''
         var dom=arguments[0];
-        var names="{";
+        var names="(";
         var len = dom.attributes.length;
         for(var i=0;i<len;i++){
             let it = dom.attributes[i];
             let localName = it.localName;
-            let value = it.value;
-            names += "'" + localName + "':'" + value.replace(/'/g,"\\\\'") + "', ";  
+            //let value = it.value;
+            //names += "'" + localName + "':'" + value.replace(/'/g,"\\\\'") + "', ";  
+            names += "'" + localName + "',";  
         }
-        names+="}"
+        names+=")"
         return names;  
         '''
-        return eval(self.run_script(js))
+        attrs = dict()
+        for attr in eval(self.run_script(js)):
+            attrs[attr] = self.attr(attr)
+        return attrs
 
     @property
     def text(self) -> str:
@@ -67,19 +71,31 @@ class DriverElement(DrissionElement):
     @property
     def parent(self):
         """父级元素"""
-        loc = 'xpath', './..'
-        return self.ele(loc, timeout=1, show_errmsg=False)
+        return self.parents()
 
     @property
     def next(self):
         """下一个兄弟元素"""
-        loc = 'xpath', './following-sibling::*[1]'
-        return self.ele(loc, timeout=1, show_errmsg=False)
+        return self.nexts()
 
     @property
     def prev(self):
         """上一个兄弟元素"""
-        loc = 'xpath', './preceding-sibling::*[1]'
+        return self.prevs()
+
+    def parents(self, num: int = 1):
+        """N层父级元素"""
+        loc = 'xpath', f'.{"/.." * num}'
+        return self.ele(loc, timeout=1, show_errmsg=False)
+
+    def nexts(self, num: int = 1):
+        """下N个兄弟元素"""
+        loc = 'xpath', f'./following-sibling::*[{num}]'
+        return self.ele(loc, timeout=1, show_errmsg=False)
+
+    def prevs(self, num: int = 1):
+        """上N个兄弟元素"""
+        loc = 'xpath', f'./preceding-sibling::*[{num}]'
         return self.ele(loc, timeout=1, show_errmsg=False)
 
     def attr(self, attr: str) -> str:
